==> freeplane-1.9.8-1-any.pkg.tar.zst: usr/share/freeplane/resources/templates/BuzanMap.mm <==
<map version="freeplane 1.9.8">
<!--To view this file, download free mind mapping software Freeplane from http://freeplane.sourceforge.net -->
<node TEXT="Central&#xa;Idea" FOLDED="false" ID="ID_191153586" CREATED="1610381622013" MODIFIED="1610381622013" ICON_SIZE="36 pt" LINK="menuitem:_ExternalImageAddAction" STYLE="oval">
<font SIZE="22"/>
<hook NAME="MapStyle">
    <properties edgeColorConfiguration="#808080ff,#ff0000ff,#0000ffff,#00ff00ff,#ff00ffff,#00ffffff,#7c0000ff,#00007cff,#007c00ff,#7c007cff,#007c7cff,#7c7c00ff" fit_to_viewport="false"/>

<map_styles>
<stylenode LOCALIZED_TEXT="styles.root_node" STYLE="oval" UNIFORM_SHAPE="true" VGAP_QUANTITY="24 pt">
<font SIZE="24"/>
<stylenode LOCALIZED_TEXT="styles.predefined" POSITION="right" STYLE="bubble">
<stylenode LOCALIZED_TEXT="default" ID="ID_12905907" ICON_SIZE="12 pt" COLOR="#000000" STYLE="fork">
<arrowlink SHAPE="CUBIC_CURVE" COLOR="#000000" WIDTH="2" TRANSPARENCY="200" DASH="" FONT_SIZE="9" FONT_FAMILY="SansSerif" DESTINATION="ID_12905907" STARTARROW="DEFAULT"/>
<font NAME="SansSerif" SIZE="10" BOLD="false" ITALIC="false"/>
<richcontent CONTENT-TYPE="plain/auto" TYPE="DETAILS"/>
<richcontent TYPE="NOTE" CONTENT-TYPE="plain/auto"/>
</stylenode>
<stylenode LOCALIZED_TEXT="defaultstyle.details"/>
<stylenode LOCALIZED_TEXT="defaultstyle.attributes">
<font SIZE="9"/>
</stylenode>
<stylenode LOCALIZED_TEXT="defaultstyle.note" COLOR="#000000" BACKGROUND_COLOR="#ffffff" TEXT_ALIGN="LEFT"/>
<stylenode LOCALIZED_TEXT="defaultstyle.floating">
<edge STYLE="hide_edge"/>
<cloud COLOR="#f0f0f0" SHAPE="ROUND_RECT"/>
</stylenode>
<stylenode LOCALIZED_TEXT="defaultstyle.selection" BACKGROUND_COLOR="#4e85f8" BORDER_COLOR_LIKE_EDGE="false" BORDER_COLOR="#4e85f8"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.user-defined" POSITION="right" STYLE="bubble">
<stylenode LOCALIZED_TEXT="styles.topic" COLOR="#18898b" STYLE="fork">
<font NAME="Liberation Sans" SIZE="10" BOLD="true"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.subtopic" COLOR="#cc3300" STYLE="fork">
<font NAME="Liberation Sans" SIZE="10" BOLD="true"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.subsubtopic" COLOR="#669900">
<font NAME="Liberation Sans" SIZE="10" BOLD="true"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.important" ID="ID_520072399">
<icon BUILTIN="yes"/>
<arrowlink COLOR="#003399" DESTINATION="ID_520072399"/>
</stylenode>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.AutomaticLayout" POSITION="right" STYLE="bubble">
<stylenode LOCALIZED_TEXT="AutomaticLayout.level.root" ICON_SIZE="64 pt" COLOR="#000000" STYLE="oval" SHAPE_HORIZONTAL_MARGIN="10 pt" SHAPE_VERTICAL_MARGIN="10 pt">
<font NAME="Segoe Print" SIZE="22"/>
<edge COLOR="#ffffff"/>
</stylenode>
<stylenode LOCALIZED_TEXT="AutomaticLayout.level,1" ICON_SIZE="32 px" COLOR="#000000" BACKGROUND_COLOR="#ffffcc" STYLE="bubble" SHAPE_HORIZONTAL_MARGIN="2.6 pt" SHAPE_VERTICAL_MARGIN="2.6 pt" BORDER_WIDTH_LIKE_EDGE="true">
<font SIZE="18" BOLD="false" ITALIC="true"/>
<edge STYLE="sharp_bezier" WIDTH="8"/>
</stylenode>
<stylenode LOCALIZED_TEXT="AutomaticLayout.level,2" ICON_SIZE="28 px" COLOR="#000000" BORDER_WIDTH_LIKE_EDGE="true">
<font SIZE="16"/>
<edge STYLE="bezier" WIDTH="4"/>
</stylenode>
<stylenode LOCALIZED_TEXT="AutomaticLayout.level,3" ICON_SIZE="24 px" COLOR="#000000" BORDER_WIDTH_LIKE_EDGE="true">
<font SIZE="14"/>
<edge STYLE="bezier" WIDTH="3"/>
</stylenode>
<stylenode LOCALIZED_TEXT="AutomaticLayout.level,4" ICON_SIZE="24 px" COLOR="#111111" BORDER_WIDTH_LIKE_EDGE="true">
<font SIZE="13"/>
<edge STYLE="bezier" WIDTH="2"/>
</stylenode>
<stylenode LOCALIZED_TEXT="AutomaticLayout.level,5" ICON_SIZE="24 px" BORDER_WIDTH_LIKE_EDGE="true">
<font SIZE="12"/>
<edge STYLE="bezier" WIDTH="1"/>
</stylenode>
<stylenode LOCALIZED_TEXT="AutomaticLayout.level,6" ICON_SIZE="24 px">
<edge STYLE="bezier"/>
</stylenode>
<stylenode LOCALIZED_TEXT="AutomaticLayout.level,7" ICON_SIZE="16 px">
<font SIZE="10"/>
<edge STYLE="bezier"/>
</stylenode>
<stylenode LOCALIZED_TEXT="AutomaticLayout.level,8" ICON_SIZE="16 px">
<edge STYLE="bezier"/>
</stylenode>
<stylenode LOCALIZED_TEXT="AutomaticLayout.level,9" ICON_SIZE="16 px">
<edge STYLE="bezier"/>
</stylenode>
<stylenode LOCALIZED_TEXT="AutomaticLayout.level,10" ICON_SIZE="16 px">
<edge STYLE="bezier"/>
</stylenode>
<stylenode LOCALIZED_TEXT="AutomaticLayout.level,11" ICON_SIZE="16 px">
<edge STYLE="bezier"/>
</stylenode>
</stylenode>
</stylenode>
</map_styles>
</hook>
<hook NAME="AutomaticEdgeColor" COUNTER="15" RULE="ON_BRANCH_CREATION"/>
<hook NAME="accessories/plugins/AutomaticLayout.properties" VALUE="ALL"/>
<edge COLOR="#ffffff"/>
<richcontent TYPE="DETAILS">

<html>
  <head>
    
  </head>
  <body>
    <p>
      1. Write the central idea
    </p>
    <p>
      2. Save the map
    </p>
    <p>
      3. Select central node,
    </p>
    <p>
      &#160;&#160;&#160;&#160;click on icon to add picture
    </p>
    <p>
      4. Delete menu links Add image..
    </p>
    <p>
      &#160;&#160;&#160;&#160;with CTRL+K and delete field with link
    </p>
    <p>
      5. Delete node details with right click on mouse
    </p>
    <p>
      &#160;&#160;&#160;&#160;on central node - Remove node details
    </p>
  </body>
</html>
</richcontent>
<node TEXT="IDEA 1" POSITION="right" ID="ID_273436263" CREATED="1610381622018" MODIFIED="1610381622018" HGAP_QUANTITY="91.2683 pt" VSHIFT_QUANTITY="-30.73171 pt">
<edge COLOR="#007c7c"/>
<node TEXT="IDEA 1.1" ID="ID_588194298" CREATED="1610381622019" MODIFIED="1610381622019" HGAP_QUANTITY="15.7561 pt" VSHIFT_QUANTITY="-12.29268 pt"/>
<node TEXT="IDEA 1.2" ID="ID_1104103844" CREATED="1610381622019" MODIFIED="1610381622019"/>
</node>
<node TEXT="IDEA 2" POSITION="right" ID="ID_495676614" CREATED="1610381622019" MODIFIED="1610381622019" HGAP_QUANTITY="101.80488 pt" VSHIFT_QUANTITY="-42.14634 pt">
<edge COLOR="#009900"/>
<node TEXT="IDEA 2.1" ID="ID_744391648" CREATED="1610381622019" MODIFIED="1610381622019" HGAP_QUANTITY="15.7561 pt" VSHIFT_QUANTITY="-14.92683 pt"/>
<node TEXT="IDEA 2.2" ID="ID_903669612" CREATED="1610381622019" MODIFIED="1610381622019"/>
</node>
<node TEXT="IDEA 3" POSITION="right" ID="ID_90823870" CREATED="1610381622019" MODIFIED="1610381622019" HGAP_QUANTITY="56.14634 pt" VSHIFT_QUANTITY="-61.46342 pt">
<edge COLOR="#ff0000"/>
<node TEXT="IDEA 3.1" ID="ID_1201198400" CREATED="1610381622019" MODIFIED="1610381622019" HGAP_QUANTITY="15.7561 pt" VSHIFT_QUANTITY="-15.80488 pt"/>
<node TEXT="IDEA 3.2" ID="ID_1615683347" CREATED="1610381622019" MODIFIED="1610381622019" HGAP_QUANTITY="17.5122 pt" VSHIFT_QUANTITY="3.5122 pt"/>
</node>
<node TEXT="IDEA 6" POSITION="left" ID="ID_25434398" CREATED="1610381622020" MODIFIED="1610381622020" HGAP_QUANTITY="73.70732 pt" VSHIFT_QUANTITY="-37.7561 pt">
<edge COLOR="#cc00ff"/>
<node TEXT="IDEA 6.1" ID="ID_352937383" CREATED="1610381622020" MODIFIED="1610381622020" HGAP_QUANTITY="13.12195 pt" VSHIFT_QUANTITY="-9.65854 pt"/>
<node TEXT="IDEA 6.2" ID="ID_966834988" CREATED="1610381622020" MODIFIED="1610381622020" HGAP_QUANTITY="15.7561 pt" VSHIFT_QUANTITY="-7.90244 pt"/>
</node>
<node TEXT="IDEA 5" POSITION="left" ID="ID_1822402846" CREATED="1610381622020" MODIFIED="1610381622020" HGAP_QUANTITY="84.24391 pt" VSHIFT_QUANTITY="-36 pt">
<edge COLOR="#ff9900"/>
<node TEXT="IDEA 5.1" ID="ID_1274507163" CREATED="1610381622020" MODIFIED="1610381622020" HGAP_QUANTITY="14 pt" VSHIFT_QUANTITY="-21.07317 pt"/>
<node TEXT="IDEA 5.2" ID="ID_1203076641" CREATED="1610381622020" MODIFIED="1610381622020"/>
</node>
<node TEXT="IDEA 4" POSITION="left" ID="ID_575079876" CREATED="1610381622020" MODIFIED="1610381622020" HGAP_QUANTITY="67.56098 pt" VSHIFT_QUANTITY="-42.14634 pt">
<edge COLOR="#0000ff"/>
<node TEXT="IDEA 4.1" ID="ID_317662625" CREATED="1610381622020" MODIFIED="1610381622020" HGAP_QUANTITY="14.87805 pt" VSHIFT_QUANTITY="-18.43903 pt"/>
<node TEXT="IDEA 4.2" ID="ID_1522387997" CREATED="1610381622021" MODIFIED="1610381622021"/>
</node>
</node>
</map>

==> freeplane-1.11.10-1-any.pkg.tar.zst: usr/share/freeplane/resources/templates/BuzanMap.mm <==
<map version="freeplane 1.9.8">
<!--To view this file, download free mind mapping software Freeplane from https://www.freeplane.org -->
<node TEXT="Central&#xa;Idea" FOLDED="false" ID="ID_191153586" CREATED="1610381622013" MODIFIED="1610381622013" ICON_SIZE="36 pt" LINK="menuitem:_ExternalImageAddAction" STYLE="oval">
<font SIZE="22"/>
<hook NAME="MapStyle">
    <properties edgeColorConfiguration="#808080ff,#ff0000ff,#0000ffff,#00ff00ff,#ff00ffff,#00ffffff,#7c0000ff,#00007cff,#007c00ff,#7c007cff,#007c7cff,#7c7c00ff" fit_to_viewport="false"/>

<map_styles>
<stylenode LOCALIZED_TEXT="styles.root_node" STYLE="oval" UNIFORM_SHAPE="true" VGAP_QUANTITY="24 pt">
<font SIZE="24"/>
<stylenode LOCALIZED_TEXT="styles.predefined" POSITION="right" STYLE="bubble">
<stylenode LOCALIZED_TEXT="default" ID="ID_12905907" ICON_SIZE="12 pt" COLOR="#000000" STYLE="fork">
<arrowlink SHAPE="CUBIC_CURVE" COLOR="#000000" WIDTH="2" TRANSPARENCY="200" DASH="" FONT_SIZE="9" FONT_FAMILY="SansSerif" DESTINATION="ID_12905907" ENDARROW="DEFAULT"/>
<font NAME="SansSerif" SIZE="10" BOLD="false" ITALIC="false"/>
<richcontent CONTENT-TYPE="plain/auto" TYPE="DETAILS"/>
<richcontent TYPE="NOTE" CONTENT-TYPE="plain/auto"/>
</stylenode>
<stylenode LOCALIZED_TEXT="defaultstyle.details"/>
<stylenode LOCALIZED_TEXT="defaultstyle.attributes">
<font SIZE="9"/>
</stylenode>
<stylenode LOCALIZED_TEXT="defaultstyle.note" COLOR="#000000" BACKGROUND_COLOR="#ffffff" TEXT_ALIGN="LEFT"/>
<stylenode LOCALIZED_TEXT="defaultstyle.floating">
<edge STYLE="hide_edge"/>
<cloud COLOR="#f0f0f0" SHAPE="ROUND_RECT"/>
</stylenode>
<stylenode LOCALIZED_TEXT="defaultstyle.selection" BACKGROUND_COLOR="#afd3f7" BORDER_COLOR_LIKE_EDGE="false" BORDER_COLOR="#afd3f7"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.user-defined" POSITION="right" STYLE="bubble">
<stylenode LOCALIZED_TEXT="styles.topic" COLOR="#18898b" STYLE="fork">
<font NAME="Liberation Sans" SIZE="10" BOLD="true"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.subtopic" COLOR="#cc3300" STYLE="fork">
<font NAME="Liberation Sans" SIZE="10" BOLD="true"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.subsubtopic" COLOR="#669900">
<font NAME="Liberation Sans" SIZE="10" BOLD="true"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.important" ID="ID_520072399">
<icon BUILTIN="yes"/>
<arrowlink COLOR="#003399" DESTINATION="ID_520072399"/>
</stylenode>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.AutomaticLayout" POSITION="right" STYLE="bubble">
<stylenode LOCALIZED_TEXT="AutomaticLayout.level.root" ICON_SIZE="64 pt" COLOR="#000000" STYLE="oval" SHAPE_HORIZONTAL_MARGIN="10 pt" SHAPE_VERTICAL_MARGIN="10 pt">
<font NAME="Segoe Print" SIZE="22"/>
<edge COLOR="#ffffff"/>
</stylenode>
<stylenode LOCALIZED_TEXT="AutomaticLayout.level,1" ICON_SIZE="32 px" COLOR="#000000" BACKGROUND_COLOR="#ffffcc" STYLE="bubble" SHAPE_HORIZONTAL_MARGIN="2.6 pt" SHAPE_VERTICAL_MARGIN="2.6 pt" BORDER_WIDTH_LIKE_EDGE="true">
<font SIZE="18" BOLD="false" ITALIC="true"/>
<edge STYLE="sharp_bezier" WIDTH="8"/>
</stylenode>
<stylenode LOCALIZED_TEXT="AutomaticLayout.level,2" ICON_SIZE="28 px" COLOR="#000000" BORDER_WIDTH_LIKE_EDGE="true">
<font SIZE="16"/>
<edge STYLE="bezier" WIDTH="4"/>
</stylenode>
<stylenode LOCALIZED_TEXT="AutomaticLayout.level,3" ICON_SIZE="24 px" COLOR="#000000" BORDER_WIDTH_LIKE_EDGE="true">
<font SIZE="14"/>
<edge STYLE="bezier" WIDTH="3"/>
</stylenode>
<stylenode LOCALIZED_TEXT="AutomaticLayout.level,4" ICON_SIZE="24 px" COLOR="#111111" BORDER_WIDTH_LIKE_EDGE="true">
<font SIZE="13"/>
<edge STYLE="bezier" WIDTH="2"/>
</stylenode>
<stylenode LOCALIZED_TEXT="AutomaticLayout.level,5" ICON_SIZE="24 px" BORDER_WIDTH_LIKE_EDGE="true">
<font SIZE="12"/>
<edge STYLE="bezier" WIDTH="1"/>
</stylenode>
<stylenode LOCALIZED_TEXT="AutomaticLayout.level,6" ICON_SIZE="24 px">
<edge STYLE="bezier"/>
</stylenode>
<stylenode LOCALIZED_TEXT="AutomaticLayout.level,7" ICON_SIZE="16 px">
<font SIZE="10"/>
<edge STYLE="bezier"/>
</stylenode>
<stylenode LOCALIZED_TEXT="AutomaticLayout.level,8" ICON_SIZE="16 px">
<edge STYLE="bezier"/>
</stylenode>
<stylenode LOCALIZED_TEXT="AutomaticLayout.level,9" ICON_SIZE="16 px">
<edge STYLE="bezier"/>
</stylenode>
<stylenode LOCALIZED_TEXT="AutomaticLayout.level,10" ICON_SIZE="16 px">
<edge STYLE="bezier"/>
</stylenode>
<stylenode LOCALIZED_TEXT="AutomaticLayout.level,11" ICON_SIZE="16 px">
<edge STYLE="bezier"/>
</stylenode>
</stylenode>
</stylenode>
</map_styles>
</hook>
<hook NAME="AutomaticEdgeColor" COUNTER="15" RULE="ON_BRANCH_CREATION"/>
<hook NAME="accessories/plugins/AutomaticLayout.properties" VALUE="ALL"/>
<edge COLOR="#ffffff"/>
<richcontent TYPE="DETAILS">

<html>
  <head>
    
  </head>
  <body>
    <p>
      1. Write the central idea
    </p>
    <p>
      2. Save the map
    </p>
    <p>
      3. Select central node,
    </p>
    <p>
      &#160;&#160;&#160;&#160;click on icon to add picture
    </p>
    <p>
      4. Delete menu links Add image..
    </p>
    <p>
      &#160;&#160;&#160;&#160;with CTRL+K and delete field with link
    </p>
    <p>
      5. Delete node details with right click on mouse
    </p>
    <p>
      &#160;&#160;&#160;&#160;on central node - Remove node details
    </p>
  </body>
</html>
</richcontent>
<node TEXT="IDEA 1" POSITION="right" ID="ID_273436263" CREATED="1610381622018" MODIFIED="1610381622018" HGAP_QUANTITY="91.2683 pt" VSHIFT_QUANTITY="-30.73171 pt">
<edge COLOR="#007c7c"/>
<node TEXT="IDEA 1.1" ID="ID_588194298" CREATED="1610381622019" MODIFIED="1610381622019" HGAP_QUANTITY="15.7561 pt" VSHIFT_QUANTITY="-12.29268 pt"/>
<node TEXT="IDEA 1.2" ID="ID_1104103844" CREATED="1610381622019" MODIFIED="1610381622019"/>
</node>
<node TEXT="IDEA 2" POSITION="right" ID="ID_495676614" CREATED="1610381622019" MODIFIED="1610381622019" HGAP_QUANTITY="101.80488 pt" VSHIFT_QUANTITY="-42.14634 pt">
<edge COLOR="#009900"/>
<node TEXT="IDEA 2.1" ID="ID_744391648" CREATED="1610381622019" MODIFIED="1610381622019" HGAP_QUANTITY="15.7561 pt" VSHIFT_QUANTITY="-14.92683 pt"/>
<node TEXT="IDEA 2.2" ID="ID_903669612" CREATED="1610381622019" MODIFIED="1610381622019"/>
</node>
<node TEXT="IDEA 3" POSITION="right" ID="ID_90823870" CREATED="1610381622019" MODIFIED="1610381622019" HGAP_QUANTITY="56.14634 pt" VSHIFT_QUANTITY="-61.46342 pt">
<edge COLOR="#ff0000"/>
<node TEXT="IDEA 3.1" ID="ID_1201198400" CREATED="1610381622019" MODIFIED="1610381622019" HGAP_QUANTITY="15.7561 pt" VSHIFT_QUANTITY="-15.80488 pt"/>
<node TEXT="IDEA 3.2" ID="ID_1615683347" CREATED="1610381622019" MODIFIED="1610381622019" HGAP_QUANTITY="17.5122 pt" VSHIFT_QUANTITY="3.5122 pt"/>
</node>
<node TEXT="IDEA 6" POSITION="left" ID="ID_25434398" CREATED="1610381622020" MODIFIED="1610381622020" HGAP_QUANTITY="73.70732 pt" VSHIFT_QUANTITY="-37.7561 pt">
<edge COLOR="#cc00ff"/>
<node TEXT="IDEA 6.1" ID="ID_352937383" CREATED="1610381622020" MODIFIED="1610381622020" HGAP_QUANTITY="13.12195 pt" VSHIFT_QUANTITY="-9.65854 pt"/>
<node TEXT="IDEA 6.2" ID="ID_966834988" CREATED="1610381622020" MODIFIED="1610381622020" HGAP_QUANTITY="15.7561 pt" VSHIFT_QUANTITY="-7.90244 pt"/>
</node>
<node TEXT="IDEA 5" POSITION="left" ID="ID_1822402846" CREATED="1610381622020" MODIFIED="1610381622020" HGAP_QUANTITY="84.24391 pt" VSHIFT_QUANTITY="-36 pt">
<edge COLOR="#ff9900"/>
<node TEXT="IDEA 5.1" ID="ID_1274507163" CREATED="1610381622020" MODIFIED="1610381622020" HGAP_QUANTITY="14 pt" VSHIFT_QUANTITY="-21.07317 pt"/>
<node TEXT="IDEA 5.2" ID="ID_1203076641" CREATED="1610381622020" MODIFIED="1610381622020"/>
</node>
<node TEXT="IDEA 4" POSITION="left" ID="ID_575079876" CREATED="1610381622020" MODIFIED="1610381622020" HGAP_QUANTITY="67.56098 pt" VSHIFT_QUANTITY="-42.14634 pt">
<edge COLOR="#0000ff"/>
<node TEXT="IDEA 4.1" ID="ID_317662625" CREATED="1610381622020" MODIFIED="1610381622020" HGAP_QUANTITY="14.87805 pt" VSHIFT_QUANTITY="-18.43903 pt"/>
<node TEXT="IDEA 4.2" ID="ID_1522387997" CREATED="1610381622021" MODIFIED="1610381622021"/>
</node>
</node>
</map>
